package controller;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import model.EntryDAO;
import model.Model;
import model.UserDAO;

import org.mybeans.dao.DAOException;
import org.mybeans.forms.FormBeanFactory;

import databean.User;

import controller.Action;
import formbean.DeleteUserForm;
import formbean.LoginForm;

public class DeleteUserAction extends Action {
	private static FormBeanFactory<DeleteUserForm> formBeanFactory =
		FormBeanFactory.getInstance(DeleteUserForm.class,"<>\"");

	private EntryDAO entryDAO;
	private UserDAO  userDAO;

	public DeleteUserAction(Model model) {
		entryDAO = model.getEntryDAO();
		userDAO  = model.getUserDAO();
	}

	public String getName() { return "delete-user"; }
    
    public String perform(HttpServletRequest request) {
		try {
			int numEntries = entryDAO.getCount();
			request.setAttribute("numEntries",numEntries);

			// Must be logged in for this one.  Don't need to redirect.
	        User user = (User) request.getSession(true).getAttribute("user");
			if (user == null) {
				request.setAttribute("form", new LoginForm());
				return "login.jsp";
			}
	
	    	User[] userList = userDAO.getAll();
			request.setAttribute("userList",userList);

			DeleteUserForm form = formBeanFactory.create(request);
	        List<String> errors = form.getValidationErrors();
	        request.setAttribute("errors",errors);
	    	if (errors.size() > 0) return "manage-users.jsp";
	    	
	    	if (!form.getButton().equals("Yes")) return "manage-users.jsp";

	    	if (user.getUserName().equals(form.getUserName())) {
	    		errors.add("Cannot delete yourself");
	    		return "manage-users.jsp";
	    	}
	    	userDAO.delete(form.getUserName());
			
			// Refresh userList because we've changed it
	    	userList = userDAO.getAll();
			request.setAttribute("userList",userList);

			request.setAttribute("message","User "+form.getUserName()+" deleted");
			return "manage-users.jsp";
		} catch (DAOException e) {
        	e.printStackTrace();
        	request.setAttribute("dbError",e.getMessage());
        	return "db-error.jsp";
		}
    }
}
