package controller;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import model.EntryDAO;
import model.Model;
import model.UserDAO;

import org.mybeans.dao.DAOException;
import org.mybeans.forms.FormBeanFactory;

import databean.User;

import controller.Action;
import formbean.LoginForm;

public class LoginAction extends Action {
	private static FormBeanFactory<LoginForm> formBeanFactory =
		FormBeanFactory.getInstance(LoginForm.class,"<>\"");

	private EntryDAO entryDAO;
	private UserDAO  userDAO;

	public LoginAction(Model model) {
		entryDAO = model.getEntryDAO();
		userDAO  = model.getUserDAO();
	}

	public String getName() { return "login"; }
    
    public String perform(HttpServletRequest request) {
        try {
			int numEntries = entryDAO.getCount();
			request.setAttribute("numEntries",numEntries);

			List<String> errors = new ArrayList<String>();
            request.setAttribute("errors",errors);

	    	User user = (User) request.getSession(true).getAttribute("user");
	    	if (user != null) {
	    		errors.add("You are already logged in.");
	    		return "search.jsp";
	    	}

			LoginForm form = formBeanFactory.create(request);
			request.setAttribute("form",form);

			if (!form.isPresent()) return "login.jsp";

	    	errors.addAll(form.getValidationErrors());
	    	if (errors.size() > 0) return "login.jsp";
	    	
	    	user = userDAO.lookup(form.getUserName());
	    	if (user == null) {
	    		errors.add("Username invalid");
	    		return "login.jsp";
	    	}
	    	
	    	if (!user.checkPassword(form.getPassword())) {
	    		errors.add("Incorrect password");
	    		return "login.jsp";
	    	}
	    	
	    	request.getSession(true).setAttribute("user",user);
	    	
	    	if (form.getRedirect().length() > 0) {
	    		return form.getRedirect();
	    	}
	    	
	    	return "search.jsp";
        } catch (DAOException e) {
        	e.printStackTrace();
        	request.setAttribute("dbError",e.getMessage());
        	return "db-error.jsp";
		}
    }
}
