package controller;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import model.EntryDAO;
import model.LogDAO;
import model.Model;

import org.mybeans.dao.DAOException;
import org.mybeans.forms.FormBeanFactory;

import databean.Entry;

import controller.Action;
import formbean.IdForm;

public class LookupEntryAction extends Action {
	private static FormBeanFactory<IdForm> formBeanFactory =
						FormBeanFactory.getInstance(IdForm.class,"<>\"");
	
	private EntryDAO entryDAO;
	private LogDAO   logDAO;

	public LookupEntryAction(Model model) {
		entryDAO = model.getEntryDAO();
		logDAO   = model.getLogDAO();
	}

    public String getName() { return "lookup-entry"; }

    public String perform(HttpServletRequest request) {
        try {
			int numEntries = entryDAO.getCount();
			request.setAttribute("numEntries",numEntries);
			
			IdForm form = formBeanFactory.create(request);
	    	List<String> errors = form.getValidationErrors();
	        request.setAttribute("errors",errors);
	    	if (errors.size() > 0) return "search.jsp";

	    	int id = form.getIdNum();
	    	Entry entry = entryDAO.lookup(id);
	    	if (entry == null) {
		    	logDAO.write(request,"lookupAction: id="+id+", entry=null");
	    		errors.add("No record with id="+id);
	    		return "search.jsp";
	    	}
	    	
	    	logDAO.write(request,"lookupAction: id="+id+", lastName="+entry.getLastName()+", firstName="+entry.getFirstNames());
	    	request.setAttribute("entry",entry);
			return "display-entry.jsp";
        } catch (DAOException e) {
        	e.printStackTrace();
        	request.setAttribute("dbError",e.getMessage());
        	return "db-error.jsp";
		}
    }
}
