package controller;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import model.EntryDAO;
import model.Model;
import model.UserDAO;

import org.mybeans.dao.DAOException;
import org.mybeans.forms.FormBeanFactory;

import databean.User;

import controller.Action;
import formbean.DeleteUserForm;
import formbean.LoginForm;
import formbean.ManageUserForm;
import formbean.SetPasswordForm;

public class ManageUsersAction extends Action {
	private static FormBeanFactory<ManageUserForm> formBeanFactory =
						FormBeanFactory.getInstance(ManageUserForm.class,"<>\"");
	
	private EntryDAO entryDAO;
	private UserDAO  userDAO;

	public ManageUsersAction(Model model) {
		entryDAO = model.getEntryDAO();
		userDAO  = model.getUserDAO();
	}

    public String getName() { return "manage-users"; }

    public String perform(HttpServletRequest request) {
        try {
			int numEntries = entryDAO.getCount();
			request.setAttribute("numEntries",numEntries);

			// Must be logged in for this one.  Don't need to redirect.
	        User user = (User) request.getSession(true).getAttribute("user");
			if (user == null) {
				request.setAttribute("form", new LoginForm());
				return "login.jsp";
			}
			
	    	User[] userList = userDAO.getAll();
			request.setAttribute("userList",userList);
			
			ManageUserForm form = formBeanFactory.create(request);
			if (!form.isPresent()) return "manage-users.jsp";
			
			List<String> errors = form.getValidationErrors();
	        request.setAttribute("errors",errors);
	    	if (errors.size() > 0) return "manage-users.jsp";

	    	if (form.getButton().equals("Delete")) {
	    		DeleteUserForm deleteForm = new DeleteUserForm();
	    		deleteForm.setUserName(form.getUserName());
	    		request.setAttribute("form",deleteForm);
	    		return "delete-user.jsp";
	    	}
	    	
	    	if (form.getButton().equals("Set Password")) {
	    		SetPasswordForm pwdForm = new SetPasswordForm();
	    		pwdForm.setUserName(form.getUserName());
	    		request.setAttribute("form",pwdForm);
	    		return "set-password.jsp";
	    	}
	    	
	    	errors.add("Unknown button: "+form.getButton());
			return "manage-users.jsp";
        } catch (DAOException e) {
        	e.printStackTrace();
        	request.setAttribute("dbError",e.getMessage());
        	return "db-error.jsp";
		}
    }
}
