package controller;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import model.EntryDAO;
import model.Model;
import model.UserDAO;

import org.mybeans.dao.DAOException;
import org.mybeans.forms.FormBeanFactory;

import databean.User;

import controller.Action;
import formbean.LoginForm;
import formbean.SetPasswordForm;

public class SetPasswordAction extends Action {
	private static FormBeanFactory<SetPasswordForm> formBeanFactory =
		FormBeanFactory.getInstance(SetPasswordForm.class,"<>\"");

	private EntryDAO entryDAO;
	private UserDAO  userDAO;

	public SetPasswordAction(Model model) {
		entryDAO = model.getEntryDAO();
		userDAO  = model.getUserDAO();
	}

	public String getName() { return "set-password"; }
    
    public String perform(HttpServletRequest request) {
		try {
			int numEntries = entryDAO.getCount();
			request.setAttribute("numEntries",numEntries);

			// Must be logged in for this one.  Don't need to redirect.
	        User user = (User) request.getSession().getAttribute("user");
			if (user == null) {
				request.setAttribute("form", new LoginForm());
				return "login.jsp";
			}
	
			SetPasswordForm form = formBeanFactory.create(request);
			request.setAttribute("form",form);
	
	        List<String> errors = form.getValidationErrors();
	        request.setAttribute("errors",errors);
	    	if (errors.size() > 0) return "set-password.jsp";

	    	userDAO.setPassword(user.getUserName(), form.getNewPassword());
			
			request.setAttribute("message","Password changed for user "+form.getUserName());
	    	User[] userList = userDAO.getAll();
			request.setAttribute("userList",userList);
			return "manage-users.jsp";
		} catch (DAOException e) {
        	e.printStackTrace();
        	request.setAttribute("dbError",e.getMessage());
        	return "db-error.jsp";
		}
    }
}
