package model;

import java.io.File;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;

import org.mybeans.dao.DAOException;

import model.EntryDAO;
import model.LogDAO;
import model.UserDAO;


public class Model {
	private LogDAO    logDAO;
	private EntryDAO  entryDAO;
	private UserDAO   userDAO;

	private String  localNetAddr;
	private String  localNetPrefix;
	private boolean requireSSL;

	public Model(ServletConfig config) throws ServletException {
		localNetAddr   = config.getInitParameter("localNetAddr");
        localNetPrefix = config.getInitParameter("localNetPrefix");
        requireSSL     = new Boolean(config.getInitParameter("requireSSL"));       

        String csvDirName = config.getInitParameter("dataDirectory");
		if (csvDirName == null || csvDirName.length() == 0) {
        	initUsingMySQL(config);
		} else {
        	initUsingCSVFiles(config);
		}
	}
	
	public EntryDAO getEntryDAO()       { return entryDAO;       }
	public String   getLocalNetAddr()   { return localNetAddr;   }
	public String   getLocalNetPrefix() { return localNetPrefix; }
	public LogDAO   getLogDAO()         { return logDAO;         }
	public boolean  getRequireSSL()     { return requireSSL;     }
	public UserDAO  getUserDAO()        { return userDAO;        }
	
	private void initUsingCSVFiles(ServletConfig config) throws ServletException {
        String dataDirectory = config.getInitParameter("dataDirectory");
       	String backupsStr = config.getInitParameter("numBackups");

       	int backups;
    	try {
    		if (backupsStr != null && backupsStr.length() > 0) {
    			backups = Integer.parseInt(backupsStr);
    		} else {
    			backups = 5;
    		}
    	} catch (NumberFormatException e) {
    		throw new ServletException("The numBackups parameter (in web.xml) is not an integer");
    	}

    	File dir = new File(dataDirectory);
    	if (!dir.exists() && !dir.mkdirs()) {
    		throw new ServletException("Could not make directory for tables: "+dataDirectory);
    	}

    	try {
	    	logDAO   = LogDAO.getCSVInstance(dir+"/log.csv");
	    	userDAO  = UserDAO.getCSVInstance(dir+"/user.csv",backups);
	    	entryDAO = EntryDAO.getCSVInstance(dir+"/entry.csv",backups);
	    } catch (DAOException e) {
	    	throw new ServletException(e);
    	}
	}

	public void initUsingMySQL(ServletConfig config) throws ServletException {
		String jdbcDriver = config.getInitParameter("jdbcDriverName");
	    String jdbcURL    = config.getInitParameter("jdbcURL");
	    String jdbcUser    = config.getInitParameter("jdbcUser");
	    String jdbcPassword    = config.getInitParameter("jdbcPassword");
	    
	    try {
	    	logDAO   = LogDAO.getSQLInstance(jdbcDriver,jdbcURL,jdbcUser,jdbcPassword);
	    	userDAO  = UserDAO.getSQLInstance(jdbcDriver,jdbcURL,jdbcUser,jdbcPassword);
	    	entryDAO = EntryDAO.getSQLInstance(jdbcDriver,jdbcURL,jdbcUser,jdbcPassword);
	    } catch (DAOException e) {
	    	throw new ServletException(e);
	    }
	}
}
