package model;

import org.mybeans.dao.DAOException;
import org.mybeans.dao.GenericDAO;
import org.mybeans.factory.BeanFactoryException;
import org.mybeans.factory.BeanTable;
import org.mybeans.factory.RollbackException;
import org.mybeans.factory.Transaction;

import databean.User;


public class UserDAO extends GenericDAO<User> {
	public static UserDAO getSQLInstance(String jdbcDriverName, String jdbcURL, String jdbcUser, String jdbcPassword) throws DAOException {
		try {
			BeanTable<User> table = BeanTable.getSQLInstance(User.class,"user",jdbcDriverName,jdbcURL,jdbcUser,jdbcPassword);
			return new UserDAO(table);
		} catch (BeanFactoryException e) {
			throw new DAOException(e);
		}
	}
	
	public static UserDAO getCSVInstance(String fileName, int backups) throws DAOException {
		try {
			BeanTable<User> table = BeanTable.getCSVInstance(User.class,fileName,backups);
			return new UserDAO(table);
		} catch (BeanFactoryException e) {
			throw new DAOException(e);
		}
	}

	private UserDAO(BeanTable<User> table) {
		super(table,"userName");
        
        // Long running web apps need to clean up idle database connections.
        // So we can tell each BeanTable to clean them up.  (You would only notice
        // a problem after leaving your web app running for several hours.)
        table.setIdleConnectionCleanup(true);
	}
	
	public void setPassword(String userName, String password) throws DAOException {
        try {
        	Transaction.begin();
			User dbUser = getFactory().lookup(userName);
			
			if (dbUser == null) {
				throw new DAOException("User "+userName+" no longer exists");
			}
			
			dbUser.setPassword(password);
			Transaction.commit();
		} catch (RollbackException e) {
			throw new DAOException(e);
		} finally {
			if (Transaction.isActive()) Transaction.rollback();
		}
	}
}
